StringBuffer

Struct StringBuffer 

pub struct StringBuffer<'a> { /* private fields */ }
A buffered String suitable for sending across as a message

Implementations

Source

impl<'a> StringBuffer<'a>

pub fn new() -> Self

Create a new StringBuffer with no backing. This will get resized as soon as data is written to it.

pub fn with_capacity(capacity: usize) -> Self

Create a new StringBuffer with enough space to hold usize characters

pub fn as_bytes(&self) -> &[u8]

pub fn as_bytes_mut(&mut self) -> &mut [u8]

pub fn as_str(&self) -> Result<&str, Utf8Error>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn clear(&mut self)

Clear the contents of this String and set the length to 0

pub fn to_str(&self) -> &str

pub unsafe fn from_memory_message(mem: &'a MemoryMessage) -> Self

Safety

This can turn any MemoryMessage into a StringBuffer, so ensure that this function is only called when the contents are a StringBuffer

pub unsafe fn from_memory_message_mut(mem: &'a mut MemoryMessage) -> Self

Safety

This can turn any MemoryMessage into a StringBuffer, so ensure that this function is only called when the contents are a StringBuffer

pub fn lend_mut(&mut self, connection: CID, id: u32) -> Result<Result, Error>

Perform a mutable lend of this String to the server.

pub fn lend(&self, connection: CID, id: u32) -> Result<Result, Error>

pub fn send(self, connection: CID, id: u32) -> Result<Result, Error>